/*******************************************************************************
 * commloop.c
 * Performs an extensive test of the communcations, looping until a failure occurs
 * Uses an EPP-like protocol on a bidirectional parallel port
 *
 * October 25, 2005
 *
 * Michael Siegenthaler
 * www.msigi.net
 *
 ******************************************************************************/
#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>

#include "eppmanual.h"

void print_error(char* errmsg);

/*******************************************************************************
 * Main function
 ******************************************************************************/
int main(int argc, char **argv) {                    

  // Variable declarations
  int addr, data, readdata;
  int has_failed = 0;

  // Make sure we have permission to use the parallel port
  if (open_port())
    print_error("Cannot open parallel port");

  do {

    // Write some values
    for (addr=0;addr<256;addr++) {
  
      //data = ~addr;
      //data = data & 0xff;
      data = addr+128;
      if (data>=256) data = data-256;
  
      if (write_dev(addr, data)) print_error("Cannot write");
  
    }
  
    // Read back and check the values
    for (addr=0;addr<256;addr++) {
  
      //data = ~addr;
      //data = data & 0xff;
      data = addr+128;
      if (data>=256) data = data-256;
  
      if (read_dev(addr, &readdata)) print_error("Cannot read");
  
      if (readdata!=data) {
        printf("Failure: Expected %x at address %x, got %x\n", data, addr, readdata);
        has_failed = 1;
      }
  
    }
  
    // Write some values
    for (addr=0;addr<256;addr++) {
  
      data = ~addr;
      data = data & 0xff;
      //data = addr+128;
      //if (data>=256) data = data-256;
  
      if (write_dev(addr, data)) print_error("Cannot write");
  
    }
  
    // Read back and check the values
    for (addr=0;addr<256;addr++) {
  
      data = ~addr;
      data = data & 0xff;
      //data = addr+128;
      //if (data>=256) data = data-256;
  
      if (read_dev(addr, &readdata)) print_error("Cannot read");
  
      if (readdata!=data) {
        printf("Failure: Expected %x at address %x, got %x\n", data, addr, readdata);
        has_failed = 1;
      }
  
    }

  } while (!has_failed);
  
  // Finished
  return 0;

}

/*******************************************************************************
 * Error routine
 * Prints an error message and syntax information
 * Parameters: option error message
 * Exits as a failure
 ******************************************************************************/
void print_error(char* errmsg) {

  if (errmsg) {
    fprintf(stderr,"ERROR: %s\n",errmsg);
  } else {
    fprintf(stderr,"ERROR: unknown error\n");
  }
  exit(1);

}
