#ifndef _MSIGI_EPPMANUAL_H
#define _MSIGI_EPPMANUAL_H

// Define the base address of the parallel port here.
// Normally this is 0x378 if you only have one parallel port.
// In my case, I have a SIIG dual parallel port ISA card, with
// one port inside the computer and one outside, so that's what
// the other base addresses are.
#define BASE 0x378              /* Integrated on motherboard */
// #define BASE 0x3bc           /* SIIG B (Inside) */
// #define BASE 0x278           /* SIIG A (Outside) */

// Timing is accomplished by busy-waiting. There is a minimum
// wait time, which depends on the parallel port speed, the FPGA
// speed, the capacitance of the control/data lines, and possibly
// other factors. There is no maximum wait time, except the latency
// which is considered acceptable by the user. There's no point in
// sleeping and yielding control to another process, since the
// waits are much shorter than a typical time slice. Right now
// a simple loop which iterates a fixed number of times is used.
// I'm using a Pentium 166MHz and a value of 500 works fine. A
// higher value may be required on a faster machine. Even better,
// a timer could be used to make the wait time independent of the
// processor speed.
#define BUSYLOOPCOUNT 500

// Number of times to retry if a read or write fails
#define MAX_EPP_RETRIES 5

// Functions
int write_dev(int addr, int data);
int read_dev(int addr, int *data);
int open_port(void);
int write_port(unsigned char value, int is_address);
int read_port(unsigned char* value, int is_address);
void set_reset();

#endif
